Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorKalyan Prasad Tatavarthi2018-09-06 10:35:37 +0000
committerKalyan Prasad Tatavarthi2018-09-06 10:51:21 +0000
commit05d6ba8048379a2e630f604c10c6b1a926e9aff1 (patch)
tree88ec9e0176ff87416b286576ae27f9127d08f0f8
parent737cccaae5f28a8b8e34e82abe89fd5f9fedd13f (diff)
downloadeclipse.platform.runtime-I20180906-0745.tar.gz
eclipse.platform.runtime-I20180906-0745.tar.xz
eclipse.platform.runtime-I20180906-0745.zip
Bug 535802 Fixes broken PropertyFileConverter.java from the EPL 2.0 conversionS4_9_0_RC2R4_9I20180906-0745R4_9_maintenance
Change-Id: I43be36bf4d309a98a0ae982be8a74857ec6699dd Signed-off-by: Kalyan Prasad Tatavarthi <kalyan_prasad@in.ibm.com>
-rw-r--r--bundles/org.eclipse.core.tools/src/org/eclipse/core/tools/nls/PropertyFileConverter.java34
1 files changed, 18 insertions, 16 deletions
diff --git a/bundles/org.eclipse.core.tools/src/org/eclipse/core/tools/nls/PropertyFileConverter.java b/bundles/org.eclipse.core.tools/src/org/eclipse/core/tools/nls/PropertyFileConverter.java
index 0c7fa3920..3c82c91e4 100644
--- a/bundles/org.eclipse.core.tools/src/org/eclipse/core/tools/nls/PropertyFileConverter.java
+++ b/bundles/org.eclipse.core.tools/src/org/eclipse/core/tools/nls/PropertyFileConverter.java
@@ -1,15 +1,16 @@
-/**********************************************************************
-.
-. This
- * program and the accompanying materials are made available under the terms of
- * the Eclipse Public License 2.0 which accompanies this distribution, and is
-t https://www.eclipse.org/legal/epl-2.0/
-t
-t SPDX-License-Identifier: EPL-2.0
+/*******************************************************************************
+ * Copyright (c) 2005 IBM Corporation and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
+ * which accompanies this distribution, and is available at
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
*
* Contributors:
* IBM - Initial API and implementation
**********************************************************************/
package org.eclipse.core.tools.nls;
import java.io.*;
@@ -93,13 +94,14 @@ public class PropertyFileConverter {
private void appendPreText(StringBuilder buffer, String pkgName, String bundleName, String typeName) {
//if this text had typos, would it be a false pretext?
buffer.append("/**********************************************************************\n"); //$NON-NLS-1$
-.
-. This\n"); //$NON-NLS-1$
- buffer.append(" * program and the accompanying materials are made available under the terms of\n"); //$NON-NLS-1$
+ buffer.append(" * Copyright (c) 2005 IBM Corporation and others.\n"); //$NON-NLS-1$
+ buffer.append(" *\n"); //$NON-NLS-1$
+ buffer.append(" * This program and the accompanying materials are made available under the terms of\n"); //$NON-NLS-1$
buffer.append(" * the Eclipse Public License 2.0 which accompanies this distribution, and is\n"); //$NON-NLS-1$
-t https://www.eclipse.org/legal/epl-2.0/
-t
-t SPDX-License-Identifier: EPL-2.0\n"); //$NON-NLS-1$
+ buffer.append(" * available at\n"); //$NON-NLS-1$
+ buffer.append(" * https://www.eclipse.org/legal/epl-2.0/\n"); //$NON-NLS-1$
+ buffer.append(" * \n"); //$NON-NLS-1$
+ buffer.append(" * SPDX-License-Identifier: EPL-2.0\n"); //$NON-NLS-1$
buffer.append(" * \n"); //$NON-NLS-1$
buffer.append(" * Contributors: \n"); //$NON-NLS-1$
buffer.append(" * IBM - Initial API and implementation\n"); //$NON-NLS-1$
@@ -1,15 +1,16 @@
*
* Contributors:
- * IBM - Initial API and implementation
- **********************************************************************/
+ * IBM Corporation - initial API and implementation
+ *******************************************************************************/
package org.eclipse.core.tools.nls;
import java.io.*;

Back to the top